server

package
v0.23.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 25, 2026 License: Apache-2.0 Imports: 27 Imported by: 0

Documentation

Overview

Package server sets up the HTTP server with all routes and middleware.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(ctx context.Context, cfg *config.Config, logger *slog.Logger) (*http.Server, func())

New creates a fully configured HTTP server and returns a cleanup function that closes all database connections on shutdown. ctx is used to control the lifetime of background workers (scheduler).

Types

This section is empty.

Directories

Path Synopsis
Package middleware provides HTTP middleware for the MemDB Go API.
Package middleware provides HTTP middleware for the MemDB Go API.

Jump to